#
# desktop_choice_text.py: choose desktop
#
# Copyright 2002 Red Hat, Inc.
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
#
# You should have received a copy of the GNU Library Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

from snack import *
from constants_text import *
from rhpl.translate import _
from constants import productName
from hdrlist import Package, Group, GroupSet

NOT_ENOUGH_CAPACITY = N_("/usr or / partition doesn't have enough space for the packages you selected. Please enlarge the disk partition (to total size of packages + 500MB or more), or reduce packages to be installed.")

class DesktopChoiceWindow:
    def __call__(self, screen, intf, instclass, dispatch, grpset, partitions, diskset):
        # Get the capacity of the disk partition.
        if partitions.getRequestByMountPoint('/usr') is None:
            capacity = partitions.getRequestByMountPoint('/').getActualSize(partitions, diskset)
        else:
            capacity = partitions.getRequestByMountPoint('/usr').getActualSize(partitions, diskset)

        # Calculate the number of packages and its total size.
        grpset.unselectAll()
        grpset.selectGroup("base")
        grpset.selectGroup("core")
        size_of_min = grpset.size()
        (gset, pset) = grpset.getSelectionState()
        pn_of_min = 1
        for (pkg, (usecount, manual_state)) in pset:
            if usecount > 0:
                pn_of_min = pn_of_min + 1
        grpset.unselectAll()
        grpset.selectGroup("everything")
        size_of_all = grpset.size()
        (gset, pset) = grpset.getSelectionState()
        pn_of_all = 1
        for (pkg, (usecount, manual_state)) in pset:
            if usecount > 0:
                pn_of_all = pn_of_all + 1

	bb = ButtonBar (screen, (TEXT_OK_BUTTON, TEXT_BACK_BUTTON))
	
        toplevel = GridFormHelp (screen, _("Package Selection"),
				 "wsdefaults", 1, 5)

        labeltxt = N_("Selection packages that to be installed.")

        toplevel.add (TextboxReflowed(55, _(labeltxt)), 0, 0, (0, 0, 0, 1))

        thegrid = Grid(1, 3)
        radio = RadioGroup()
        minimalCb = radio.add(_("Minimal (%s packages, total size: %sM)") % (pn_of_min, size_of_min), "minimal", default = 0)
        thegrid.setField(minimalCb, 0, 0, anchorLeft = 1)
        everythingCb = radio.add(_("All     (%s packages, total size: %sM)") % (pn_of_all, size_of_all), "everything", default = 1)
        thegrid.setField(everythingCb, 0, 1, anchorLeft = 1)
        customizeCb = radio.add(_("Customize the set of packages in the next step"), "customize", default = 0)
        thegrid.setField(customizeCb, 0, 2, anchorLeft = 1)

        toplevel.add(thegrid, 0, 1, padding = (0, 0, 0, 1))
        toplevel.add (bb, 0, 4, (0, 0, 0, 0), growx = 1)

        while 1:
            result = toplevel.run()
            rc = bb.buttonPressed (result)
            if rc == TEXT_BACK_CHECK:
                screen.popWindow()
                return INSTALL_BACK

            if radio.getSelection() == "customize":
                dispatch.skipStep("package-selection", skip = 0)
                grpset.unselectAll()
                grpset.selectGroup("base")
                grpset.selectGroup("core")
                break
            elif radio.getSelection() == "minimal":
                if size_of_min + 500 > capacity:
                    ButtonChoiceWindow(screen, _("Warning"), _(NOT_ENOUGH_CAPACITY),
                                                        buttons = [ _("OK") ])
                    continue
                dispatch.skipStep("package-selection")
                grpset.unselectAll()
                grpset.selectGroup("base")
                grpset.selectGroup("core")
                break
            else:
                if size_of_all + 500 > capacity:
                    ButtonChoiceWindow(screen, _("Warning"), _(NOT_ENOUGH_CAPACITY),
                                                        buttons = [ _("OK") ])
                    continue
                dispatch.skipStep("package-selection")
                grpset.unselectAll()
                grpset.selectGroup("everything")
                break
	    
	screen.popWindow()
				 
        return INSTALL_OK

