#
# driveorderdialog.py: dialog for reordering drives into BIOS order
#
# Ni Zhixin <zxni@redflag-linux.com>
#
# Copyright 2001-2005 Red Flag, Ltd.
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
#
# You should have received a copy of the GNU Library Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import iutil
import partedUtils
from snack import *
from constants_text import *
from rhpl.translate import _, N_
from rhpl.log import log


class TextDriveOrderWidget:
    """Widget to reorder drives according to BIOS drive order."""


    def __init__(self, screen, driveorder, diskset):
	self.screen = screen
	self.driveOrder = driveorder
        self.diskset = diskset
	
	high = len(self.driveOrder)
	if high > 5:
	    scroll = 1
	else:
	    scroll = 0

	self.driverOrderList = CListbox(height=high, cols=3,
                           		col_widths=[10,10,50],
                           		scroll=scroll, returnExit = 1,
                           		width=70, col_pad=2,
                           		col_labels=[_('Driver'), _('Size'), _('Model')],
                           		col_label_align=[CENTER, CENTER,CENTER])

	self.makeDriveOrderStore()

	self.bb = ButtonBar(screen, ((_("Up"), "up", "F2"),
				     (_("Down"), "down", "F3"),
				     TEXT_OK_BUTTON, TEXT_CANCEL_BUTTON))

	text = _("Arrange the drives to be in the same "
                 "order as used by the BIOS. Changing "
                 "the drive order may be useful if you "
                 "have multiple SCSI adapters or both SCSI "
                 "and IDE adapters and want to boot from "
                 "the SCSI device.\n\n"
                 "Changing the drive order will change "
                 "where the installation program "
                 "locates the Master Boot Record (MBR).")

	self.tt = TextboxReflowed(70, text)

	self.g = GridFormHelp(screen, _("Edit Drive Order"), "editdriverorder", 1, 3)
  
        self.g.add(self.tt, 0, 0)
        self.g.add(self.driverOrderList, 0, 1)
        self.g.add(self.bb, 0, 2)

    def getScreen(self):
	self.screen.pushHelpLine( _("                   F2-Up     F3-Down      F12-OK"))

        while 1:
            rc = self.g.run()
            res = self.bb.buttonPressed(rc)

            if res == "up":
                self.arrowClicked("up")
            elif res == "down":
                self.arrowClicked("down")
	    elif res == TEXT_CANCEL_CHECK:
		self.screen.popHelpLine()
                self.screen.popWindow()
		return 0
            else:
                self.screen.popHelpLine()
                self.screen.popWindow()
		return 1

    def getOrder(self):
        return self.driveOrder

    def arrowClicked(self, direction):
        drive = self.driverOrderList.current()
        if not drive:
            return

        # there has got to be a better way to do this =\
        index = self.driveOrder.index(drive)
        if direction == "up":
            self.driveOrder.remove(drive)
            self.driveOrder.insert(index - 1, drive)
        elif direction == "down":
            self.driveOrder.remove(drive)
            self.driveOrder.insert(index + 1, drive)
        self.makeDriveOrderStore()

    def makeDriveOrderStore(self):
        disks = self.diskset.disks

        self.driverOrderList.clear()
        for drive in self.driveOrder:
            # if we have it in the diskset, get the size and type of drive
	    driverstr = "/dev/%s" % (drive,)
	    sizestr = ""
	    modelstr = ""
            if disks.has_key(drive):
                size = partedUtils.getDeviceSizeMB(disks[drive].dev)
                sizestr = "%8.0f MB" %(size,)

                modelstr = disks[drive].dev.model

            self.driverOrderList.append([driverstr, sizestr, modelstr], drive,
				       col_text_align = None)

